@@ -1,5 +1,5 @@
 /*
-** Copyright 2000-2004 Double Precision, Inc.  See COPYING for
+** Copyright 2000-2006 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
@@ -27,7 +27,7 @@
 #include	"authstaticlist.h"
 #include	<ltdl.h>
 
-static const char rcsid[]="$Id: authdaemond.c,v 1.31 2005/07/07 01:30:46 mrsam Exp $";
+static const char rcsid[]="$Id: authdaemond.c,v 1.33 2006/06/01 10:47:32 mrsam Exp $";
 
 #ifndef	SOMAXCONN
 #define	SOMAXCONN	5
@@ -985,8 +985,7 @@ int start()
 		perror("open");
 		exit(1);
 	}
-	close(1);
-	dup(0);
+	dup2(0, 1);
 	sighup_pipe= pipefd[1];
 
 	do_child=startchildren(pipefd);
@@ -994,7 +993,7 @@ int start()
 	for (;;)
 	{
 		struct sockaddr	saddr;
-		int	saddr_len;
+		socklen_t saddr_len;
 		fd_set	fds;
 		struct timeval tv;
 
