@@ -27,7 +27,7 @@
 #define		SV_BEGIN_LEN		((sizeof(SV_BEGIN_MARK))-1)
 #define		SV_END_LEN		((sizeof(SV_END_MARK))-1)
 
-static const char rcsid[]="$Id: authmysqllib.c,v 1.42 2005/07/13 00:34:59 mrsam Exp $";
+static const char rcsid[]="$Id: authmysqllib.c,v 1.44 2007/02/10 02:51:06 mrsam Exp $";
 
 /* siefca@pld.org.pl */
 struct var_data {			
@@ -121,6 +121,13 @@ unsigned int server_port=0;
 unsigned int server_opt=0;
 const	char *p;
 
+const	char *sslkey;
+const	char *sslcert;
+const	char *sslcacert;
+const	char *sslcapath;
+const	char *sslcipher;
+unsigned int  use_ssl=0;
+
 /*
 ** Periodically detect dead connections.
 */
@@ -151,6 +158,19 @@ const	char *p;
 	password=read_env("MYSQL_PASSWORD");
 	database=read_env("MYSQL_DATABASE");
 
+#if MYSQL_VERSION_ID >= 32200
+	sslkey=read_env("MYSQL_SSL_KEY");
+	sslcert=read_env("MYSQL_SSL_CERT");
+	sslcacert=read_env("MYSQL_SSL_CACERT");
+	sslcapath=read_env("MYSQL_SSL_CAPATH");
+	sslcipher=read_env("MYSQL_SSL_CIPHER");
+
+	if ((sslcert != NULL) && ((sslcacert != NULL) || (sslcapath != NULL)))
+	{
+		use_ssl=1;
+	}
+#endif
+
 	server_socket=(char *) read_env("MYSQL_SOCKET");
 
 	if ((p=read_env("MYSQL_PORT")) != 0)
@@ -186,6 +206,11 @@ const	char *p;
 
 #if MYSQL_VERSION_ID >= 32200
 	mysql_init(&mysql_buf);
+	if (use_ssl)
+	{
+		mysql_ssl_set(&mysql_buf, sslkey, sslcert, sslcacert,
+			      sslcapath, sslcipher);
+	}
 	mysql=mysql_real_connect(&mysql_buf, server, userid, password,
 				 NULL,
 				 server_port,
@@ -984,7 +1009,9 @@ int auth_mysql_setpass(const char *user, const char *pass,
 
 
 	if (courier_authdebug_login_level >= 2)
+	{
 		DPRINTF("setpass SQL: %s", sql_buf);
+	}
 	if (mysql_query (mysql, sql_buf))
 	{
 		DPRINTF("setpass SQL failed");
@@ -1161,7 +1188,9 @@ void auth_mysql_enumerate( void(*cb_func)(const char *name,
 	}
 	/* NULL row could indicate end of result or an error */
 	if (mysql_errno(mysql))
+	{
 		DPRINTF("mysql error during enumeration: %s", mysql_error(mysql));
+	}
 	else
 		(*cb_func)(NULL, 0, 0, NULL, NULL, NULL, void_arg);
 
